==> feathers-mongoose-casl-dashboard-1.2.2.tgz: package/es/DashboardApp.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import Dashboard from './Dashboard';
import { Selector } from 'net-provider';

var DashboardWrapper = function (_Component) {
  _inherits(DashboardWrapper, _Component);

  function DashboardWrapper() {
    _classCallCheck(this, DashboardWrapper);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  DashboardWrapper.prototype.render = function render() {
    var _props = this.props,
        renderDefaultScreen = _props.renderDefaultScreen,
        showBreadcrumb = _props.showBreadcrumb,
        syncWithUrl = _props.syncWithUrl,
        rowSelection = _props.rowSelection,
        listTargetKeyPrefix = _props.listTargetKeyPrefix,
        url = _props.url,
        onRow = _props.onRow,
        editAfterSaved = _props.editAfterSaved;

    if (!url) {
      return renderDefaultScreen ? renderDefaultScreen(this.props) : '';
    }
    var dashboardData = this.props.dashboardData || [];
    var data = dashboardData.find(function (item) {
      return item.result.name === url;
    });
    if (!data) return '...';
    var dashboardConfig = data.data.dashboardConfig || {};
    return React.createElement(Dashboard, {
      key: url,
      url: url,
      canCreate: data.result.canCreate,
      canUpdate: data.result.canUpdate,
      canDelete: data.result.canDelete,
      updateFields: data.result.updateFields,
      createFields: data.result.createFields,
      dashboardConfig: dashboardConfig,
      jsonSchema: data.schema,
      showBreadcrumb: showBreadcrumb,
      syncWithUrl: syncWithUrl,
      rowSelection: rowSelection,
      listTargetKeyPrefix: listTargetKeyPrefix,
      populate: dashboardConfig.populate,
      dashboardData: dashboardData,
      onRow: onRow,
      editAfterSaved: editAfterSaved
    });
  };

  return DashboardWrapper;
}(Component);

var DashboardApp = function (_Component2) {
  _inherits(DashboardApp, _Component2);

  function DashboardApp() {
    _classCallCheck(this, DashboardApp);

    return _possibleConstructorReturn(this, _Component2.apply(this, arguments));
  }

  DashboardApp.prototype.render = function render() {
    var _this3 = this;

    return React.createElement(
      Selector,
      { targetKey: 'dashboard' },
      function (_ref) {
        var data = _ref.data;

        return React.createElement(DashboardWrapper, _extends({ dashboardData: data }, _this3.props));
      }
    );
  };

  return DashboardApp;
}(Component);

export { DashboardApp as default };


DashboardWrapper.defaultProps = {
  syncWithUrl: true,
  showBreadcrumb: true,
  editAfterSaved: true
};

==> feathers-mongoose-casl-dashboard-1.3.6.tgz: package/es/DashboardApp.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { Selector } from 'net-provider';
import Dashboard from './Dashboard';

var DashboardWrapper = function (_Component) {
  _inherits(DashboardWrapper, _Component);

  function DashboardWrapper() {
    _classCallCheck(this, DashboardWrapper);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  DashboardWrapper.prototype.render = function render() {
    var _props = this.props,
        renderDefaultScreen = _props.renderDefaultScreen,
        showBreadcrumb = _props.showBreadcrumb,
        syncWithUrl = _props.syncWithUrl,
        rowSelection = _props.rowSelection,
        listTargetKeyPrefix = _props.listTargetKeyPrefix,
        url = _props.url,
        onRow = _props.onRow,
        editAfterSaved = _props.editAfterSaved,
        customRenderField = _props.customRenderField,
        customElements = _props.customElements;

    if (!url) {
      return renderDefaultScreen ? renderDefaultScreen(this.props) : '';
    }
    var dashboardData = this.props.dashboardData || [];
    var data = dashboardData.find(function (item) {
      return item.result.name === url;
    });
    if (!data) return '...';
    var dashboardConfig = data.data.dashboardConfig || {};
    return React.createElement(Dashboard, {
      key: url,
      url: url,
      canCreate: data.result.canCreate,
      canUpdate: data.result.canUpdate,
      canDelete: data.result.canDelete,
      updateFields: data.result.updateFields,
      createFields: data.result.createFields,
      dashboardConfig: dashboardConfig,
      jsonSchema: data.schema,
      showBreadcrumb: showBreadcrumb,
      syncWithUrl: syncWithUrl,
      rowSelection: rowSelection,
      listTargetKeyPrefix: listTargetKeyPrefix,
      populate: dashboardConfig.populate,
      dashboardData: dashboardData,
      onRow: onRow,
      editAfterSaved: editAfterSaved,
      customRenderField: customRenderField,
      customElements: customElements
    });
  };

  return DashboardWrapper;
}(Component);

var DashboardApp = function (_Component2) {
  _inherits(DashboardApp, _Component2);

  function DashboardApp() {
    _classCallCheck(this, DashboardApp);

    return _possibleConstructorReturn(this, _Component2.apply(this, arguments));
  }

  DashboardApp.prototype.render = function render() {
    var _this3 = this;

    return React.createElement(
      Selector,
      { targetKey: 'dashboard' },
      function (_ref) {
        var data = _ref.data;
        return React.createElement(DashboardWrapper, _extends({ dashboardData: data }, _this3.props));
      }
    );
  };

  return DashboardApp;
}(Component);

export { DashboardApp as default };


DashboardWrapper.defaultProps = {
  syncWithUrl: true,
  showBreadcrumb: true,
  editAfterSaved: true
};
